;; In `checkdoc-show-diagnostics', the instruction:
;; 
;;       (pop-to-buffer b)
;;       ...
;;       (other-window -1)
;;       
;; put the buffer/window configuration into a state checkdock is not
;; able to cope with: the current buffer becomes the wrong one.  Then
;; `checkdoc-current-buffer' ends up checking a buffer unrelated with
;; the buffer that was current when entering the function
;; `checkdoc-current-buffer'.
;; 
;; The test below shows that `checkdoc-current-buffer' ends up checking
;; the buffer named "*NOT THE BUFFER TO CHECK*" instead of the buffer
;; named "test-checkdoc-buffer.el".
;; 
;; 1. `eval-buffer' will reproduce it interactively.
;; 
;; 2. Shell command:
;; 
;;      emacs -Q  --batch --eval='(progn (find-file "./test-checkdoc-buffer.el") (eval-buffer))'
;;      
;;    will reproduce it in a raw emacs.

(defun my-bad-documented-function ()
  (let (;; The buffer we would like to check
        (to-check   (get-buffer "test-checkdoc-buffer.el"))
        ;; The buffer the checkdoc will say is (partly) checked.
        (bad-buffer (get-buffer-create "*NOT THE BUFFER TO CHECK*"))
        )
    ;; Initialize buffers for successive reproducible tests
    (switch-to-buffer "*Style Warnings*")
    (let ((inhibit-read-only t))
      (erase-buffer))

    (switch-to-buffer bad-buffer)
    (erase-buffer)
    (insert "(setq my-bad 2)   \n")

    
    (switch-to-buffer bad-buffer)

    ;; Running checkdoc, supposedly on the buffer `to-check'.
    (save-excursion
      (with-current-buffer to-check
        ;; (save-window-excursion (missing-debug-function 'checkdoc-current-buffer))
        ;; (save-window-excursion (missing-debug-function 'checkdoc-comments))
        (checkdoc-current-buffer :take-notes)
        ))

    ;; Testing if we got an warning/error from the `bad-buffer'.
    (let ((got-bad-buffer-message
           (save-excursion 
             (switch-to-buffer "*Style Warnings*")
             (goto-char (point-min))
             (search-forward (concat (format "#<buffer %s>" bad-buffer)
                                     ":1: White space found at end of line")
                             nil
                             :no-error
                             )))
          )
      (if got-bad-buffer-message
          (error "ERROR `checkdoc-current-buffer' didn't check the current buffer")
        (print "Test ok."))
      )))
                        
(my-bad-documented-function)


(provide 'test-checkdoc-buffer)

;;; test-checkdoc-buffer.el ends here
